@@ -17,13 +17,15 @@
 #include <vector>
 #include <map>
 
-#ifndef ICE_OS_UWP
-#   if defined(_WIN32)
-#      include <process.h>
-#   else
-#      include <sys/types.h>
-#      include <cstddef>
-#   endif
+#if defined(_WIN32)
+#    include <process.h>
+#else
+#    include <sys/types.h>
+#    include <cstddef>
+#endif
+
+#ifdef ICE_SWIFT
+#   include <dispatch/dispatch.h>
 #endif
 
 //
