@@ -11,9 +11,6 @@
 #include <Ice/InputStream.h>
 #include <Ice/Initialize.h>
 #include <IceUtil/StringUtil.h>
-#ifdef ICE_OS_UWP
-#    include <Ice/StringConverter.h>
-#endif
 #include <iomanip>
 
 using namespace std;
@@ -30,27 +27,7 @@ socketErrorToString(int error)
     {
         return "unknown error";
     }
-#ifdef ICE_OS_UWP
-    if(error == E_ACCESSDENIED)
-    {
-        ostringstream os;
-        os << "access to a resource or feature is denied, ensure that you have requested the appropriate\n";
-        os << "capability and made the required declarations in the package manifest of your app.";
-        return os.str();
-    }
-    else
-    {
-        //
-        // Don't need to use a wide string converter as the wide string come
-        // from Windows API.
-        //
-        return wstringToString(
-            static_cast<Windows::Networking::Sockets::SocketErrorStatus>(error).ToString()->Data(),
-            getProcessStringConverter());
-    }
-#else
     return IceUtilInternal::errorToString(error);
-#endif
 }
 
 };
@@ -461,11 +438,7 @@ Ice::DNSException::ice_print(ostream& out) const
 {
     Exception::ice_print(out);
     out << ":\nDNS error: ";
-#ifdef ICE_OS_UWP
-    out << socketErrorToString(error);
-#else
     out << errorToStringDNS(error);
-#endif
     out << "\nhost: " << host;
 }
 
