@@ -12,11 +12,7 @@
 namespace IceInternal
 {
 
-#ifdef ICE_OS_UWP
-struct ICE_API Address;
-#else
 union Address;
-#endif
 
 }
 
