@@ -292,10 +292,7 @@ Ice::PropertiesI::load(const std::string& file)
 {
     StringConverterPtr stringConverter = getProcessStringConverter();
 
-//
-// UWP applications cannot access Windows registry.
-//
-#if defined (_WIN32) && !defined(ICE_OS_UWP)
+#if defined (_WIN32)
     if(file.find("HKCU\\") == 0 || file.find("HKLM\\") == 0)
     {
         HKEY key = file.find("HKCU\\") == 0 ? HKEY_CURRENT_USER : HKEY_LOCAL_MACHINE;
@@ -700,13 +697,9 @@ void
 Ice::PropertiesI::loadConfig()
 {
     string value = getProperty("Ice.Config");
-#ifndef ICE_OS_UWP
-    //
-    // UWP cannot access environment variables
-    //
     if(value.empty() || value == "1")
     {
-#   ifdef _WIN32
+#ifdef _WIN32
         vector<wchar_t> v(256);
         DWORD ret = GetEnvironmentVariableW(L"ICE_CONFIG", &v[0], static_cast<DWORD>(v.size()));
         if(ret >= v.size())
@@ -722,15 +715,14 @@ Ice::PropertiesI::loadConfig()
         {
             value = "";
         }
-#   else
+#else
        const char* s = getenv("ICE_CONFIG");
        if(s && *s != '\0')
        {
            value = s;
        }
-#   endif
-    }
 #endif
+    }
 
     if(!value.empty())
     {
