@@ -18,10 +18,6 @@
 #include <climits>
 #include <exception>
 
-#ifdef ICE_OS_UWP
-#   include <thread>
-#endif
-
 #ifndef _WIN32
     #include <sys/time.h>
     #include <sys/resource.h>
@@ -30,245 +26,7 @@
 using namespace std;
 using namespace IceInternal;
 
-#ifdef ICE_OS_UWP
-
-IceUtil::ThreadControl::ThreadControl() :
-    _id(this_thread::get_id())
-{
-}
-
-IceUtil::ThreadControl::ThreadControl(const shared_ptr<thread>& thread) :
-    _thread(thread),
-    _id(_thread->get_id())
-{
-}
-
-bool
-IceUtil::ThreadControl::operator==(const ThreadControl& rhs) const
-{
-    return id() == rhs.id();
-}
-
-bool
-IceUtil::ThreadControl::operator!=(const ThreadControl& rhs) const
-{
-    return id() != rhs.id();
-}
-
-void
-IceUtil::ThreadControl::join()
-{
-    if(!_thread)
-    {
-        throw BadThreadControlException(__FILE__, __LINE__);
-    }
-
-    try
-    {
-        _thread->join();
-    }
-    catch(const system_error& ex)
-    {
-        throw ThreadSyscallException(__FILE__, __LINE__, ex.code().value());
-    }
-}
-
-void
-IceUtil::ThreadControl::detach()
-{
-    if(!_thread)
-    {
-        throw BadThreadControlException(__FILE__, __LINE__);
-    }
-
-    try
-    {
-        _thread->detach();
-    }
-    catch(const system_error& ex)
-    {
-        throw ThreadSyscallException(__FILE__, __LINE__, ex.code().value());
-    }
-}
-
-IceUtil::ThreadControl::ID
-IceUtil::ThreadControl::id() const
-{
-    return _id;
-}
-
-void
-IceUtil::ThreadControl::sleep(const Time& timeout)
-{
-    IceUtil::Int64 msTimeout = timeout.toMilliSeconds();
-    if(msTimeout < 0 || msTimeout > 0x7FFFFFFF)
-    {
-        throw IceUtil::InvalidTimeoutException(__FILE__, __LINE__, timeout);
-    }
-    this_thread::sleep_for(chrono::microseconds(timeout.toMicroSeconds()));
-}
-
-void
-IceUtil::ThreadControl::yield()
-{
-    this_thread::yield();
-}
-
-IceUtil::Thread::Thread() :
-    _started(false),
-    _running(false)
-{
-}
-
-IceUtil::Thread::Thread(const string& name) :
-    _name(name),
-    _started(false),
-    _running(false)
-{
-}
-
-IceUtil::Thread::~Thread()
-{
-}
-
-static unsigned int
-WINAPI startHook(void* arg)
-{
-    // Ensure that the thread doesn't go away until run() has
-    // completed.
-    //
-    IceUtil::ThreadPtr thread;
-
-    try
-    {
-        IceUtil::Thread* rawThread = static_cast<IceUtil::Thread*>(arg);
-
-        //
-        // Ensure that the thread doesn't go away until run() has
-        // completed.
-        //
-        thread = rawThread;
-
-        //
-        // Initialize the random number generator in each thread on
-        // Windows (the rand() seed is thread specific).
-        //
-        unsigned int seed = static_cast<unsigned int>(IceUtil::Time::now().toMicroSeconds());
-        srand(seed ^ static_cast<unsigned int>(hash<thread::id>()(thread->getThreadControl().id())));
-
-        //
-        // See the comment in IceUtil::Thread::start() for details.
-        //
-        rawThread->__decRef();
-        thread->run();
-    }
-    catch(...)
-    {
-        if(!thread->name().empty())
-        {
-            consoleErr << thread->name() << " terminating" << endl;
-        }
-        std::terminate();
-    }
-
-    thread->_done();
-
-    return 0;
-}
-
-#include <process.h>
-
-IceUtil::ThreadControl
-IceUtil::Thread::start(size_t)
-{
-    return start(0, 0);
-}
-
-IceUtil::ThreadControl
-IceUtil::Thread::start(size_t, int)
-{
-    //
-    // Keep this alive for the duration of start
-    //
-    IceUtil::ThreadPtr keepMe = this;
-
-    IceUtil::Mutex::Lock lock(_stateMutex);
-
-    if(_started)
-    {
-        throw ThreadStartedException(__FILE__, __LINE__);
-    }
-
-    //
-    // It's necessary to increment the reference count since the
-    // thread constructor won't necessarily call the thread function until
-    // later. If the user does (new MyThread)->start() then the thread
-    // object could be deleted before the thread object takes
-    // ownership. It's also necessary to increment the reference count
-    // prior to calling the thread constructor since the thread start hook
-    // itself calls __decRef().
-    //
-    try
-    {
-        __incRef();
-        _thread.reset(new thread(startHook, this));
-    }
-    catch(const std::system_error&)
-    {
-        __decRef();
-        throw;
-    }
-
-    _started = true;
-    _running = true;
-
-    return ThreadControl(_thread);
-}
-
-IceUtil::ThreadControl
-IceUtil::Thread::getThreadControl() const
-{
-    IceUtil::Mutex::Lock lock(_stateMutex);
-    if(!_started)
-    {
-        throw ThreadNotStartedException(__FILE__, __LINE__);
-    }
-    return ThreadControl(_thread);
-}
-
-bool
-IceUtil::Thread::operator==(const Thread& rhs) const
-{
-    return this == &rhs;
-}
-
-bool
-IceUtil::Thread::operator<(const Thread& rhs) const
-{
-    return this < &rhs;
-}
-
-bool
-IceUtil::Thread::isAlive() const
-{
-    IceUtil::Mutex::Lock lock(_stateMutex);
-    return _running;
-}
-
-void
-IceUtil::Thread::_done()
-{
-    IceUtil::Mutex::Lock lock(_stateMutex);
-    _running = false;
-}
-
-const string&
-IceUtil::Thread::name() const
-{
-    return _name;
-}
-
-#elif defined(_WIN32)
+#if defined(_WIN32)
 
 IceUtil::ThreadControl::ThreadControl() :
     _handle(0),
