@@ -12,20 +12,9 @@
 #include <Ice/Properties.h>
 #include <IceUtil/StringUtil.h>
 
-#ifdef ICE_OS_UWP
-#   include <ppltasks.h> // For Concurrency::task
-#endif
-
 using namespace std;
 using namespace Ice;
 using namespace IceInternal;
-#ifdef ICE_OS_UWP
-using namespace Platform;
-using namespace Windows::Foundation;
-using namespace Windows::Storage::Streams;
-using namespace Windows::Networking;
-using namespace Windows::Networking::Sockets;
-#endif
 
 IceUtil::Shared* IceInternal::upCast(UdpTransceiver* p) { return p; }
 
@@ -35,11 +24,10 @@ IceInternal::UdpTransceiver::getNativeInfo()
     return this;
 }
 
-#if defined(ICE_USE_IOCP) || defined(ICE_OS_UWP)
+#if defined(ICE_USE_IOCP)
 AsyncInfo*
 IceInternal::UdpTransceiver::getAsyncInfo(SocketOperation status)
 {
-#if defined(ICE_USE_IOCP)
     switch(status)
     {
     case SocketOperationRead:
@@ -50,10 +38,6 @@ IceInternal::UdpTransceiver::getAsyncInfo(SocketOperation status)
         assert(false);
         return 0;
     }
-#elif defined(ICE_OS_UWP)
-    UNREFERENCED_PARAMETER(status);
-    return &_write;
-#endif
 }
 #endif
 
@@ -69,19 +53,6 @@ IceInternal::UdpTransceiver::initialize(Buffer& /*readBuffer*/, Buffer& /*writeB
     {
 #if defined(ICE_USE_IOCP)
         doFinishConnectAsync(_fd, _write);
-#elif defined(ICE_OS_UWP)
-        if(_write.error != ERROR_SUCCESS)
-        {
-            try
-            {
-                checkConnectErrorCode(__FILE__, __LINE__, _write.error);
-            }
-            catch(Ice::DNSException& ex)
-            {
-                ex.host = wstringToString(_addr.host->RawName->Data(), Ice::getProcessStringConverter());
-                throw;
-            }
-        }
 #else
         doFinishConnect(_fd);
 #endif
@@ -102,17 +73,6 @@ IceInternal::UdpTransceiver::closing(bool, const Ice::LocalException&)
 void
 IceInternal::UdpTransceiver::close()
 {
-#ifdef ICE_OS_UWP
-    IceUtil::Mutex::Lock lock(_mutex);
-    if(_readPending)
-    {
-        assert(_received.empty());
-        completed(SocketOperationRead);
-        _readPending = false;
-    }
-    _received.clear();
-#endif
-
     assert(_fd != INVALID_SOCKET);
     SOCKET fd = _fd;
     _fd = INVALID_SOCKET;
@@ -178,9 +138,6 @@ IceInternal::UdpTransceiver::write(Buffer& buf)
     {
         return SocketOperationNone;
     }
-#ifdef ICE_OS_UWP
-    return SocketOperationWrite;
-#else
     assert(buf.i == buf.b.begin());
     assert(_fd != INVALID_SOCKET && _state >= StateConnected);
 
@@ -192,11 +149,11 @@ repeat:
     ssize_t ret;
     if(_state == StateConnected)
     {
-#   ifdef _WIN32
+#ifdef _WIN32
         ret = ::send(_fd, reinterpret_cast<const char*>(&buf.b[0]), static_cast<int>(buf.b.size()), 0);
-#   else
+#else
         ret = ::send(_fd, reinterpret_cast<const char*>(&buf.b[0]), buf.b.size(), 0);
-#   endif
+#endif
     }
     else
     {
@@ -215,13 +172,13 @@ repeat:
             throw SocketException(__FILE__, __LINE__, 0);
         }
 
-#   ifdef _WIN32
+#ifdef _WIN32
         ret = ::sendto(_fd, reinterpret_cast<const char*>(&buf.b[0]), static_cast<int>(buf.b.size()), 0,
                        &_peerAddr.sa, len);
-#   else
+#else
         ret = ::sendto(_fd, reinterpret_cast<const char*>(&buf.b[0]), buf.b.size(), 0,
                        &_peerAddr.sa, len);
-#   endif
+#endif
     }
 
     if(ret == SOCKET_ERROR)
@@ -242,7 +199,6 @@ repeat:
     assert(ret == static_cast<ssize_t>(buf.b.size()));
     buf.i = buf.b.end();
     return SocketOperationNone;
-#endif
 }
 
 SocketOperation
@@ -252,10 +208,6 @@ IceInternal::UdpTransceiver::read(Buffer& buf)
     {
         return SocketOperationNone;
     }
-#ifdef ICE_OS_UWP
-    return SocketOperationRead;
-#else
-
     assert(buf.i == buf.b.begin());
     assert(_fd != INVALID_SOCKET);
 
@@ -334,12 +286,12 @@ repeat:
         //
         assert(_incoming); // Client connections should always be connected at this point.
 
-#   ifndef NDEBUG
+#ifndef NDEBUG
         bool connected = doConnect(_fd, _peerAddr, Address());
         assert(connected);
-#   else
+#else
         doConnect(_fd, _peerAddr, Address());
-#   endif
+#endif
         _state = StateConnected;
 
         if(_instance->traceLevel() >= 1)
@@ -352,10 +304,9 @@ repeat:
     buf.b.resize(static_cast<size_t>(ret));
     buf.i = buf.b.end();
     return SocketOperationNone;
-#endif
 }
 
-#if defined(ICE_USE_IOCP) || defined(ICE_OS_UWP)
+#if defined(ICE_USE_IOCP)
 bool
 IceInternal::UdpTransceiver::startWrite(Buffer& buf)
 {
@@ -365,105 +316,6 @@ IceInternal::UdpTransceiver::startWrite(Buffer& buf)
     assert(min(_maxPacketSize, _sndSize - _udpOverhead) >= static_cast<int>(buf.b.size()));
     assert(_fd != INVALID_SOCKET);
 
-#ifdef ICE_OS_UWP
-    if(_state < StateConnected)
-    {
-        try
-        {
-            bool multicast = isMulticast(_addr) || isAddressValid(_mcastAddr);
-            if(!multicast)
-            {
-                auto operation = safe_cast<DatagramSocket^>(_fd)->ConnectAsync(_addr.host, _addr.port);
-                if(!checkIfErrorOrCompleted(SocketOperationConnect, operation, operation->Status))
-                {
-                    operation->Completed = ref new AsyncActionCompletedHandler(
-                        [this] (IAsyncAction^ info, Windows::Foundation::AsyncStatus status)
-                        {
-                            //
-                            // COMPILERFIX with v141 using operator!= and operator== inside
-                            // a lambda callback triggers a compiler bug, we move the code to
-                            // a seperate private method to workaround the issue.
-                            //
-                            connectCompleted(info, status);
-                        });
-                }
-                else
-                {
-                    _write.count = 0;
-                    _write.error = ERROR_SUCCESS;
-                    _writer = ref new DataWriter(safe_cast<DatagramSocket^>(_fd)->OutputStream);
-                }
-            }
-            else
-            {
-                auto operation = safe_cast<DatagramSocket^>(_fd)->GetOutputStreamAsync(_addr.host, _addr.port);
-                if(!checkIfErrorOrCompleted(SocketOperationConnect, operation, operation->Status))
-                {
-                    operation->Completed = ref new AsyncOperationCompletedHandler<IOutputStream^>(
-                        [=](IAsyncOperation<IOutputStream^>^ info, Windows::Foundation::AsyncStatus status)
-                        {
-                            //
-                            // COMPILERFIX with v141 using operator!= and operator== inside
-                            // a lambda callback triggers a compiler bug, we move the code to
-                            // a seperate private method to workaround the issue.
-                            //
-                            getOutputStreamMcastCompleted(info, status);
-                        });
-                }
-                else
-                {
-                    _write.count = 0;
-                    _write.error = ERROR_SUCCESS;
-                    _writer = ref new DataWriter(operation->GetResults());
-                    if(_mcastAddr.host != nullptr)
-                    {
-                        setMcastGroup(_fd, _mcastAddr, "");
-                    }
-                }
-            }
-        }
-        catch(Platform::Exception^ ex)
-        {
-            checkConnectErrorCode(__FILE__, __LINE__, ex->HResult);
-        }
-        return false;
-    }
-    else if(_state == StateNotConnected)
-    {
-        try
-        {
-            DatagramSocket^ fd = safe_cast<DatagramSocket^>(_fd);
-            concurrency::create_task(fd->GetOutputStreamAsync(_peerAddr.host, _peerAddr.port)).then(
-                [=, &buf](concurrency::task<IOutputStream^> task)
-                {
-                    //
-                    // COMPILERFIX with v141 using operator!= and operator== inside
-                    // a lambda callback triggers a compiler bug, we move the code to
-                    // a seperate private method to workaround the issue.
-                    //
-                    getOutputStreamCompleted(task, buf);
-                });
-        }
-        catch(Platform::Exception^ ex)
-        {
-            checkErrorCode(__FILE__, __LINE__, ex->HResult);
-        }
-        return true;
-    }
-    else
-    {
-        try
-        {
-            _writer->WriteBytes(ref new Array<unsigned char>(&*buf.i, static_cast<int>(buf.b.size())));
-            queueOperation(SocketOperationWrite, _writer->StoreAsync());
-        }
-        catch(Platform::Exception^ ex)
-        {
-            checkErrorCode(__FILE__, __LINE__, ex->HResult);
-        }
-        return true;
-    }
-#else
     _write.buf.len = static_cast<int>(buf.b.size());
     _write.buf.buf = reinterpret_cast<char*>(&*buf.i);
     _write.error = ERROR_SUCCESS;
@@ -506,68 +358,8 @@ IceInternal::UdpTransceiver::startWrite(Buffer& buf)
         }
     }
     return true;
-#endif
 }
 
-#ifdef ICE_OS_UWP
-void
-IceInternal::UdpTransceiver::connectCompleted(Windows::Foundation::IAsyncAction^ action,
-                                              Windows::Foundation::AsyncStatus status)
-{
-    if(status != Windows::Foundation::AsyncStatus::Completed)
-    {
-        _write.error = action->ErrorCode.Value;
-    }
-    else
-    {
-        _write.error = ERROR_SUCCESS;
-        _writer = ref new DataWriter(safe_cast<DatagramSocket^>(_fd)->OutputStream);
-    }
-    _write.count = 0;
-    completed(SocketOperationConnect);
-}
-
-void
-IceInternal::UdpTransceiver::getOutputStreamMcastCompleted(IAsyncOperation<IOutputStream^>^ operation,
-                                                           Windows::Foundation::AsyncStatus status)
-{
-    if(status != Windows::Foundation::AsyncStatus::Completed)
-    {
-        _write.error = operation->ErrorCode.Value;
-    }
-    else
-    {
-        _write.error = ERROR_SUCCESS;
-        _writer = ref new DataWriter(operation->GetResults());
-    }
-    _write.count = 0;
-    if(_mcastAddr.host != nullptr)
-    {
-        setMcastGroup(_fd, _mcastAddr, "");
-    }
-    completed(SocketOperationConnect);
-}
-
-void
-IceInternal::UdpTransceiver::getOutputStreamCompleted(concurrency::task<IOutputStream^> task, Buffer& buf)
-{
-    try
-    {
-        DataWriter^ writer = ref new DataWriter(task.get());
-        writer->WriteBytes(ref new Array<unsigned char>(&*buf.i, static_cast<int>(buf.b.size())));
-        DataWriterStoreOperation^ operation = writer->StoreAsync();
-        queueOperation(SocketOperationWrite, operation);
-    }
-    catch(Platform::Exception^ pex)
-    {
-        _write.count = 0;
-        _write.error = pex->HResult;
-        completed(SocketOperationWrite);
-    }
-}
-
-#endif
-
 void
 IceInternal::UdpTransceiver::finishWrite(Buffer& buf)
 {
@@ -578,7 +370,6 @@ IceInternal::UdpTransceiver::finishWrite(Buffer& buf)
 
     if(_write.error != ERROR_SUCCESS)
     {
-#ifndef ICE_OS_UWP
         WSASetLastError(_write.error);
         if(connectionLost())
         {
@@ -588,9 +379,6 @@ IceInternal::UdpTransceiver::finishWrite(Buffer& buf)
         {
             throw SocketException(__FILE__, __LINE__, getSocketErrno());
         }
-#else
-        checkErrorCode(__FILE__, __LINE__, _write.error);
-#endif
     }
 
     assert(static_cast<size_t>(_write.count) == buf.b.size());
@@ -604,7 +392,6 @@ IceInternal::UdpTransceiver::startRead(Buffer& buf)
     buf.b.resize(packetSize);
     buf.i = buf.b.begin();
     assert(!buf.b.empty() && buf.i != buf.b.end());
-#ifndef ICE_OS_UWP
     _read.buf.len = packetSize;
     _read.buf.buf = reinterpret_cast<char*>(&*buf.i);
     _read.error = ERROR_SUCCESS;
@@ -640,55 +427,11 @@ IceInternal::UdpTransceiver::startRead(Buffer& buf)
             }
         }
     }
-#else
-    IceUtil::Mutex::Lock lock(_mutex);
-    assert(!_readPending);
-    if(!_received.empty())
-    {
-        completed(SocketOperationRead);
-    }
-    else
-    {
-        _readPending = true;
-    }
-#endif
 }
 
 void
 IceInternal::UdpTransceiver::finishRead(Buffer& buf)
 {
-#ifdef ICE_OS_UWP
-    IceUtil::Mutex::Lock lock(_mutex);
-    assert(!_readPending && (!_received.empty() || _fd == INVALID_SOCKET));
-    if(_fd == INVALID_SOCKET)
-    {
-        return;
-    }
-
-    DatagramSocketMessageReceivedEventArgs^ args = _received.front();
-    _received.pop_front();
-
-    int ret = 0;
-    try
-    {
-        DataReader^ reader = args->GetDataReader();
-        // Truncate received data if too large.
-        ret = min(static_cast<int>(reader->UnconsumedBufferLength), static_cast<int>(buf.b.size()));
-
-        Array<unsigned char>^ data = ref new Array<unsigned char>(ret);
-        reader->ReadBytes(data);
-        memcpy(&*buf.i, data->Data, ret);
-        if(_state == StateNotConnected)
-        {
-            _peerAddr.host = args->RemoteAddress;
-            _peerAddr.port = args->RemotePort;
-        }
-    }
-    catch(Platform::Exception^ ex)
-    {
-        checkErrorCode(__FILE__, __LINE__, ex->HResult);
-    }
-#else
     if(_read.error != ERROR_SUCCESS)
     {
         WSASetLastError(_read.error);
@@ -719,7 +462,6 @@ IceInternal::UdpTransceiver::finishRead(Buffer& buf)
     }
 
     int ret = _read.count;
-#endif
 
     buf.b.resize(ret);
     buf.i = buf.b.end();
@@ -757,14 +499,7 @@ IceInternal::UdpTransceiver::toString() const
     }
     else
     {
-#ifndef ICE_OS_UWP
         s << fdToString(_fd);
-#else
-        Address localAddr;
-        fdToLocalAddress(_fd, localAddr);
-        s << "local address = " << addrToString(localAddr);
-        s << "\nremote address = " << addrToString(_addr);
-#endif
     }
 
     if(isAddressValid(_mcastAddr))
@@ -800,15 +535,6 @@ Ice::ConnectionInfoPtr
 IceInternal::UdpTransceiver::getInfo() const
 {
     Ice::UDPConnectionInfoPtr info = ICE_MAKE_SHARED(Ice::UDPConnectionInfo);
-#if defined(ICE_OS_UWP)
-    if(isMulticast(_addr) || isAddressValid(_mcastAddr))
-    {
-        info->remotePort = 0;
-        info->localPort = 0;
-        info->mcastPort = 0;
-        return info;
-    }
-#endif
     if(_fd == INVALID_SOCKET)
     {
         return info;
@@ -875,16 +601,9 @@ IceInternal::UdpTransceiver::effectivePort() const
 
 IceInternal::UdpTransceiver::UdpTransceiver(const ProtocolInstancePtr& instance,
                                             const Address& addr,
-#ifdef ICE_OS_UWP
-                                            const Address&,
-                                            const string&,
-                                            int
-#else
                                             const Address& sourceAddr,
                                             const string& mcastInterface,
-                                            int mcastTtl
-#endif
-                                            ) :
+                                            int mcastTtl) :
     _instance(instance),
     _incoming(false),
     _bound(false),
@@ -893,15 +612,12 @@ IceInternal::UdpTransceiver::UdpTransceiver(const ProtocolInstancePtr& instance,
 #if defined(ICE_USE_IOCP)
     , _read(SocketOperationRead),
     _write(SocketOperationWrite)
-#elif defined(ICE_OS_UWP)
-    , _readPending(false)
 #endif
 {
     _fd = createSocket(true, _addr);
     setBufSize(-1, -1);
     setBlock(_fd, false);
 
-#ifndef ICE_OS_UWP
     _mcastAddr.saStorage.ss_family = AF_UNSPEC;
     _peerAddr.saStorage.ss_family = AF_UNSPEC; // Not initialized yet.
 
@@ -932,23 +648,6 @@ IceInternal::UdpTransceiver::UdpTransceiver(const ProtocolInstancePtr& instance,
     {
         _state = StateConnected;
     }
-#else
-    DatagramSocket^ socket = safe_cast<DatagramSocket^>(_fd);
-    IceUtil::Handle<UdpTransceiver> self(this);
-# if _WIN32_WINNT >= 0x0A00
-    // On Windows 10, it's necessary to set this property to allow Win32 applications to
-    // bind to the same multicast address
-    if(isMulticast(_addr))
-    {
-        socket->Control->MulticastOnly = true;
-    }
-# endif
-    socket->MessageReceived += ref new TypedEventHandler<DatagramSocket^, DatagramSocketMessageReceivedEventArgs^>(
-        [=](DatagramSocket^ fd, DatagramSocketMessageReceivedEventArgs^ args)
-        {
-            self->appendMessage(args);
-        });
-#endif
 
 #ifdef ICE_USE_IOCP
     //
@@ -971,9 +670,7 @@ IceInternal::UdpTransceiver::UdpTransceiver(const UdpEndpointIPtr& endpoint, con
     _mcastInterface(mcastInterface),
     _port(port),
     _state(connect ? StateNeedConnect : StateNotConnected)
-#ifdef ICE_OS_UWP
-    , _readPending(false)
-#elif defined(ICE_USE_IOCP)
+#if defined(ICE_USE_IOCP)
     , _read(SocketOperationRead),
     _write(SocketOperationWrite)
 #endif
@@ -982,28 +679,10 @@ IceInternal::UdpTransceiver::UdpTransceiver(const UdpEndpointIPtr& endpoint, con
     setBufSize(-1, -1);
     setBlock(_fd, false);
 
-#ifndef ICE_OS_UWP
     memset(&_mcastAddr.saStorage, 0, sizeof(sockaddr_storage));
     memset(&_peerAddr.saStorage, 0, sizeof(sockaddr_storage));
     _peerAddr.saStorage.ss_family = AF_UNSPEC;
     _mcastAddr.saStorage.ss_family = AF_UNSPEC;
-#else
-    DatagramSocket^ socket = safe_cast<DatagramSocket^>(_fd);
-# if _WIN32_WINNT >= 0x0A00
-    // On Windows 10, it's necessary to set this property to allow Win32 applications to
-    // bind to the same multicast address
-    if(isMulticast(_addr))
-    {
-        socket->Control->MulticastOnly = true;
-    }
-# endif
-    IceUtil::Handle<UdpTransceiver> self(this);
-    socket->MessageReceived += ref new TypedEventHandler<DatagramSocket^, DatagramSocketMessageReceivedEventArgs^>(
-        [=](DatagramSocket^ fd, DatagramSocketMessageReceivedEventArgs^ args)
-        {
-            self->appendMessage(args);
-        });
-#endif
 }
 
 IceInternal::UdpTransceiver::~UdpTransceiver()
@@ -1119,32 +798,6 @@ IceInternal::UdpTransceiver::setBufSize(int rcvSize, int sndSize)
     }
 }
 
-#ifdef ICE_OS_UWP
-void
-IceInternal::UdpTransceiver::appendMessage(DatagramSocketMessageReceivedEventArgs^ args)
-{
-    IceUtil::Mutex::Lock lock(_mutex);
-    if(_fd == INVALID_SOCKET) // Transceiver was closed.
-    {
-        return;
-    }
-    _received.push_back(args);
-
-    //
-    // If the transceiver is waiting to read a message, notify the
-    // selector that the transceiver is ready for read. This will in
-    // turn cause finishRead() to be called. If the transceiver is
-    // ready for read, we just queue the message. It will be picked
-    // up by startRead() when it is invoked.
-    //
-    if(_readPending)
-    {
-        completed(SocketOperationRead);
-        _readPending = false;
-    }
-}
-#endif
-
 //
 // The maximum IP datagram size is 65535. Subtract 20 bytes for the IP header and 8 bytes for the UDP header
 // to get the maximum payload.
