@@ -2,10 +2,12 @@
 // Copyright (c) ZeroC, Inc. All rights reserved.
 //
 
+// TODO codecvt was deprecated in C++17 and cause build failures in C++17 mode
+// For VC++ we should replace this code with MultiByteToWideChar() and WideCharToMultiByte()
 #if defined(_MSC_VER) && (_MSVC_LANG >= 201703L)
-    // TODO codecvt was deprecated in C++17 and cause build failures with VC++ compiler
-    // we should replace this code with MultiByteToWideChar() and WideCharToMultiByte()
 #   define  _SILENCE_CXX17_CODECVT_HEADER_DEPRECATION_WARNING
+#elif (__cplusplus >= 201703L)
+#   include <IceUtil/DisableWarnings.h>
 #endif
 
 #include <IceUtil/StringConverter.h>
