@@ -2433,14 +2433,11 @@ Slice::CsGenerator::writeSerializeDeserializeCode(Output &out,
 string
 Slice::CsGenerator::toArrayAlloc(const string& decl, const string& sz)
 {
-    int count = 0;
     string::size_type pos = decl.size();
     while(pos > 1 && decl.substr(pos - 2, 2) == "[]")
     {
-        ++count;
         pos -= 2;
     }
-    assert(count > 0);
 
     ostringstream o;
     o << decl.substr(0, pos) << '[' << sz << ']' << decl.substr(pos + 2);
