@@ -1027,82 +1027,5 @@ allTests(Test::TestHelper* helper)
 
         cout << "ok" << endl;
     }
-
-    //
-    // On Windows, the FD limit is very high and there's no way to limit the number of FDs
-    // for the server so we don't run this test.
-    //
-#if !defined(_WIN32) && (!defined(__APPLE__) || TARGET_OS_IPHONE == 0)
-    {
-        cout << "testing FD limit... " << flush;
-
-        RemoteObjectAdapterPrxPtr adapter = com->createObjectAdapter("Adapter", "default");
-
-        TestIntfPrxPtr test = adapter->getTestIntf();
-        int i = 0;
-        while(true)
-        {
-            try
-            {
-                ostringstream os;
-                os << i;
-                test->ice_connectionId(os.str())->ice_ping();
-                ++i;
-            }
-            catch(const Ice::LocalException&)
-            {
-                break;
-            }
-        }
-
-        try
-        {
-            ostringstream os;
-            os << i;
-            test->ice_connectionId(os.str())->ice_ping();
-            test(false);
-        }
-        catch(const Ice::ConnectionRefusedException&)
-        {
-            // Close the connection now to free a FD (it could be done after the sleep but
-            // there could be race condition since the connection might not be closed
-            // immediately due to threading).
-            test->ice_connectionId("0")->ice_getConnection()->close(
-                Ice::ICE_SCOPED_ENUM(ConnectionClose, GracefullyWithWait));
-
-            //
-            // The server closed the acceptor, wait one second and retry after freeing a FD.
-            //
-            IceUtil::ThreadControl::sleep(IceUtil::Time::milliSeconds(1100));
-            int nRetry = 10;
-            bool success = false;
-            while(--nRetry > 0)
-            {
-                try
-                {
-                    ostringstream os;
-                    os << i;
-                    test->ice_connectionId(os.str())->ice_ping();
-                    success = true;
-                    break;
-                }
-                catch(const Ice::LocalException&)
-                {
-                }
-                IceUtil::ThreadControl::sleep(IceUtil::Time::milliSeconds(100));
-            }
-            test(success);
-        }
-        catch(const Ice::LocalException&)
-        {
-            // The server didn't close the acceptor but we still get a failure (it's possible
-            // that the client reached the FD limit depending on the server we are running
-            // against...).
-        }
-
-        cout << "ok" << endl;
-    }
-#endif
-
     com->shutdown();
 }
