@@ -9,7 +9,8 @@ clientProps = lambda process, current: { "ServerDir" : current.getBuildDir("serv
 traceProps = {
     "Ice.Trace.Network" : 2,
     "Ice.Trace.Retry" : 1,
-    "Ice.Trace.Protocol" : 1
+    "Ice.Trace.Protocol" : 1,
+    "Ice.ACM.Client.Heartbeat": 2
 }
 
 if isinstance(platform, Windows) or os.getuid() != 0:
