@@ -366,6 +366,7 @@ namespace Ice
                     test(Compare(arr2S, arrS));
                 }
 
+                #if !NET8_0_OR_GREATER // See #1549
                 {
                     Serialize.Small small = new Serialize.Small();
                     small.i = 99;
@@ -376,6 +377,7 @@ namespace Ice
                     var small2 =(Serialize.Small)inS.readSerializable();
                     test(small2.i == 99);
                 }
+                #endif
 
                 {
                     short[] arr = { 0x01, 0x11, 0x12, 0x22 };
