@@ -739,6 +739,8 @@ export class Client extends TestHelper
             const connection = await cl.ice_getConnection();
             if(connection !== null)
             {
+                test(!cl.ice_isFixed());
+                test(cl.ice_fixed(connection).ice_isFixed());
                 await cl.ice_fixed(connection).getContext();
                 test(cl.ice_secure(true).ice_fixed(connection).ice_isSecure());
                 test(cl.ice_facet("facet").ice_fixed(connection).ice_getFacet() == "facet");
