@@ -1,4 +1,4 @@
-classdef OptionalFormat < uint32
+classdef OptionalFormat < uint8
     % OptionalFormat   Summary of OptionalFormat
     %
     % The optional type.
@@ -9,14 +9,15 @@ classdef OptionalFormat < uint32
 
     % Copyright (c) ZeroC, Inc. All rights reserved.
 
-    enumeration
-        F1 (0)
-        F2 (1)
-        F4 (2)
-        F8 (3)
-        Size (4)
-        VSize (5)
-        FSize (6)
-        Class (7)
+    % Don't use an enumeration as comparing enumerators with integral values is significantly slower.
+    properties(Constant)
+        F1 = uint8(0)
+        F2 = uint8(1)
+        F4 = uint8(2)
+        F8 = uint8(3)
+        Size = uint8(4)
+        VSize = uint8(5)
+        FSize = uint8(6)
+        Class = uint8(7)
     end
 end
