@@ -1018,6 +1018,12 @@ Ice_ObjectPrx_ice_fixed(void* self, void** r, void* connection)
     return 0;
 }
 
+mxArray*
+Ice_ObjectPrx_ice_isFixed(void* self)
+{
+    return createResultValue(createBool(deref<Ice::ObjectPrx>(self)->ice_isFixed()));
+}
+
 mxArray*
 Ice_ObjectPrx_ice_getConnection(void* self, void** r)
 {
