@@ -1364,7 +1364,7 @@ classdef Twoways
             assert(p.opByte1(hex2dec('FF')) == hex2dec('FF'));
             assert(p.opShort1(hex2dec('7FFF')) == hex2dec('7FFF'));
             assert(p.opInt1(hex2dec('7FFFFFFF')) == hex2dec('7FFFFFFF'));
-            %assert(p.opLong1(0x7FFFFFFFFFFFFFFF) == 0x7FFFFFFFFFFFFFFF);
+            assert(p.opLong1(int64(9223372036854775807)) == int64(9223372036854775807)); % 0x7FFFFFFFFFFFFFFF
             assert(p.opFloat1(1.0) == single(1.0));
             assert(p.opDouble1(1.0) == 1.0);
             assert(strcmp(p.opString1('opString1'), 'opString1'));
