@@ -1340,7 +1340,7 @@ BOOL _returnsData;
                             if(response)
                             {
                                 NSMutableData* outEncaps =
-                                    [NSMutableData dataWithBytes:outP.first length:(outP.second - outP.first)];
+                                    [NSMutableData dataWithBytes:outP.first length:static_cast<NSUInteger>(outP.second - outP.first)];
                                 response(ret, outEncaps);
                             }
                         },
@@ -1371,7 +1371,7 @@ BOOL _returnsData;
                             if(response)
                             {
                                 NSMutableData* outEncaps =
-                                    [NSMutableData dataWithBytes:outP.first length:(outP.second - outP.first)];
+                                    [NSMutableData dataWithBytes:outP.first length:static_cast<NSUInteger>(outP.second - outP.first)];
                                 response(ret, outEncaps);
                             }
                         },
@@ -1385,7 +1385,7 @@ BOOL _returnsData;
                {
                    std::pair<const ::Ice::Byte*, const ::Ice::Byte*> outP;
                    ret = OBJECTPRX->_iceI_end_ice_invoke(outP, r);
-                   *outEncaps = [NSMutableData dataWithBytes:outP.first length:(outP.second - outP.first)];
+                   *outEncaps = [NSMutableData dataWithBytes:outP.first length:static_cast<NSUInteger>(outP.second - outP.first)];
                }, result);
     return ret;
 }
@@ -1629,6 +1629,10 @@ BOOL _returnsData;
     @throw nsex;
     return nil; // Keep the compiler happy.
 }
+-(BOOL) ice_isFixed
+{
+    return OBJECTPRX->ice_isFixed();
+}
 -(id) ice_connectionId:(NSString*)connectionId
 {
     return [[self class] iceObjectPrxWithObjectPrx:OBJECTPRX->ice_connectionId(fromNSString(connectionId))];
