@@ -174,6 +174,11 @@ IcePHP::ResultCallback::ResultCallback()
 
 IcePHP::ResultCallback::~ResultCallback()
 {
+#ifdef NDEBUG
+    // BUGFIX releasing this object triggers an assert in zend_weakrefs_notify
+    // see https://github.com/zeroc-ice/ice/issues/1439
+    zval_ptr_dtor(&zv);
+#endif
 }
 
 void
@@ -317,7 +322,7 @@ IcePHP::OperationI::function()
 
         string fixed = fixIdent(name);
 
-        _zendFunction = static_cast<zend_internal_function*>(emalloc(sizeof(zend_internal_function)));
+        _zendFunction = static_cast<zend_internal_function*>(ecalloc(1, sizeof(zend_internal_function)));
         _zendFunction->type = ZEND_INTERNAL_FUNCTION;
         _zendFunction->function_name = zend_string_init(STRCAST(fixed.c_str()), static_cast<uint32_t>(fixed.length()), 0);
         _zendFunction->scope = proxyClassEntry;
@@ -616,19 +621,13 @@ IcePHP::TypedInvocation::unmarshalResults(int argc, zval* args, zval* ret,
     for(ResultCallbackList::iterator q = outParamCallbacks.begin(); q != outParamCallbacks.end(); ++q, ++i)
     {
         assert(Z_ISREF(args[i]));
-
-        //
-        // We must explicitly destroy the existing contents of all zvals passed
-        // as out parameters, otherwise leaks occur.
-        //
         zval* arg = Z_REFVAL_P(&args[i]);
-        zval_ptr_dtor(arg);
-        ZVAL_DUP(arg, &(*q)->zv);
+        ZVAL_COPY(arg, &(*q)->zv);
     }
 
     if(_op->returnType)
     {
-        ZVAL_DUP(ret, &retCallback->zv);
+        ZVAL_COPY(ret, &retCallback->zv);
     }
 }
 
@@ -668,12 +667,11 @@ IcePHP::TypedInvocation::unmarshalException(zval* zex, const pair<const Ice::Byt
             {
                 StreamUtil::setSlicedDataMember(ex, slicedData);
             }
-            ZVAL_DUP(zex, ex);
+            ZVAL_COPY(zex, ex);
             return;
         }
         else
         {
-            zval_ptr_dtor(ex);
             Ice::UnknownUserException uue(__FILE__, __LINE__,
                                           "operation raised undeclared exception `" + info->id + "'");
             convertException(zex, uue);
@@ -730,7 +728,7 @@ IcePHP::SyncTypedInvocation::invoke(INTERNAL_FUNCTION_PARAMETERS)
     //
     // Retrieve the arguments.
     //
-    zval* args = static_cast<zval*>(emalloc(ZEND_NUM_ARGS() * sizeof(zval)));
+    zval* args = static_cast<zval*>(ecalloc(1, ZEND_NUM_ARGS() * sizeof(zval)));
     AutoEfree autoArgs(args); // Call efree on return
     if(zend_get_parameters_array_ex(ZEND_NUM_ARGS(), args) == FAILURE)
     {
@@ -794,6 +792,7 @@ IcePHP::SyncTypedInvocation::invoke(INTERNAL_FUNCTION_PARAMETERS)
                 }
 
                 zval ex;
+                ZVAL_UNDEF(&ex);
                 unmarshalException(&ex, rb);
                 if(!Z_ISUNDEF(ex))
                 {
