@@ -232,7 +232,6 @@ IcePHP::idToClass(const string& id)
 #else
     string cls = scopedToName(id, false);
 #endif
-
     return nameToClass(cls);
 }
 
@@ -617,8 +616,6 @@ convertLocalException(const Ice::LocalException& ex, zval* zex)
 void
 IcePHP::convertException(zval* zex, const Ice::Exception& ex)
 {
-    ZVAL_UNDEF(zex);
-
     ostringstream ostr;
     ostr << ex;
     string str = ostr.str();
@@ -742,18 +739,9 @@ throwError(const string& name, const string& msg)
     {
         return;
     }
+    zend_class_entry* cls = nameToClass(name);
+    assert(cls);
     zval ex;
-    // AutoDestroy destroy(&ex);
-
-    zend_class_entry* cls;
-    {
-        zend_class_entry* p;
-        zend_string* s = zend_string_init(STRCAST(name.c_str()), static_cast<int>(name.size()), 0);
-        p = zend_lookup_class(s);
-        zend_string_release(s);
-        assert(p);
-        cls = p;
-    }
     if(object_init_ex(&ex, cls) == FAILURE)
     {
         assert(false);
@@ -768,7 +756,6 @@ throwError(const string& name, const string& msg)
     }
 
     zend_throw_exception_object(&ex);
-    // destroy.release();
 }
 
 void
@@ -822,7 +809,6 @@ invokeMethodHelper(zval* obj, const string& name, zval* param)
     zval ret, method;
     ZVAL_STRING(&method, STRCAST(name.c_str()));
     uint32_t numParams = param ? 1 : 0;
-    // zval** params = param ? &param : 0;
     int status = 0;
     zend_try
     {
@@ -853,7 +839,9 @@ IcePHP::invokeMethod(zval* obj, const string& name, const string& arg)
 {
     zval param;
     ZVAL_STRINGL(&param, STRCAST(arg.c_str()), static_cast<int>(arg.size()));
-    return invokeMethodHelper(obj, name, &param);
+    AutoDestroy destroy(&param);
+    bool retval = invokeMethodHelper(obj, name, &param);
+    return retval;
 }
 
 bool
