@@ -20,8 +20,17 @@
 #    undef _POSIX_C_SOURCE
 #endif
 
+#ifdef _WIN32
+    // suppress C4100: '_unused_op': unreferenced formal parameter in Python 3.12 cpython/unicodeobject.h
+#   pragma warning( disable : 4100)
+#endif
+
 #include <Python.h>
 
+#ifdef _WIN32
+#   pragma warning( default : 4100)
+#endif
+
 #ifdef STRCAST
 #   error "STRCAST already defined!"
 #endif
