@@ -225,7 +225,12 @@ IcePy::getFunction()
     //
     // Get name of current function.
     //
+    // Use PyEval_GetFrame with Pyhthon >= 3.11
+#if PY_VERSION_HEX >= 0x030B0000
+    PyFrameObject *f = PyEval_GetFrame();
+#else
     PyFrameObject *f = PyThreadState_GET()->frame;
+#endif
     PyObjectHandle code = getAttr(reinterpret_cast<PyObject*>(f), "f_code", false);
     assert(code.get());
     PyObjectHandle func = getAttr(code.get(), "co_name", false);
