@@ -85,6 +85,12 @@ def allTests(helper, communicator, collocated):
     test(b1.ice_getIdentity().name == "test" and b1.ice_getIdentity().category == "category" and \
          len(b1.ice_getAdapterId()) == 0)
 
+    b1 = communicator.stringToProxy("test:tcp --sourceAddress \"::1\"")
+    test(b1 == communicator.stringToProxy(b1.ice_toString()))
+
+    b1 = communicator.stringToProxy("test:udp --sourceAddress \"::1\" --interface \"0:0:0:0:0:0:0:1%lo\"")
+    test(b1 == communicator.stringToProxy(b1.ice_toString()))
+
     b1 = communicator.stringToProxy("test@adapter")
     test(b1.ice_getIdentity().name == "test" and len(b1.ice_getIdentity().category) == 0 and \
          b1.ice_getAdapterId() == "adapter")
@@ -620,6 +626,7 @@ def allTests(helper, communicator, collocated):
     test(cl == base)
     test(derived == base)
     test(cl == derived)
+    test(Test.MyDerivedClassPrx.checkedCast(cl, "facet") == None)
 
     loc = Ice.LocatorPrx.checkedCast(base)
     test(loc == None)
@@ -654,6 +661,8 @@ def allTests(helper, communicator, collocated):
     sys.stdout.flush()
     connection = cl.ice_getConnection()
     if connection != None:
+        test(cl.ice_isFixed() == False)
+        test(cl.ice_fixed(connection).ice_isFixed())
         cl.ice_fixed(connection).getContext()
         test(cl.ice_secure(True).ice_fixed(connection).ice_isSecure())
         test(cl.ice_facet("facet").ice_fixed(connection).ice_getFacet() == "facet")
