@@ -51,6 +51,11 @@
 // BUGFIX: Workaround unused parameter in ruby.h header file
 //
 #if defined(__clang__)
+// BUGFIX: Workaround clang 13 warnings during ruby macro expansion, it is important to put this before the push/pop
+// directives to keep the warnings ignored in the source files where macros are expanded.
+#   if __clang_major__ >= 13
+#       pragma clang diagnostic ignored "-Wcompound-token-split-by-macro"
+#   endif
 #   pragma clang diagnostic push
 #   pragma clang diagnostic ignored "-Wunused-parameter"
 //
@@ -59,6 +64,7 @@
 #   pragma clang diagnostic ignored "-Wconversion"
 
 // Silence warnings regarding missing deprecation attributes in ruby headers
+#   pragma clang diagnostic ignored "-Wdocumentation"
 #   pragma clang diagnostic ignored "-Wdocumentation-deprecated-sync"
 #elif defined(__GNUC__)
 #   pragma GCC diagnostic push
@@ -70,6 +76,10 @@
 
 #include <ruby.h>
 
+#ifdef HAVE_RUBY_ENCODING_H
+#  include <ruby/encoding.h>
+#endif
+
 #if defined(__clang__)
 #   pragma clang diagnostic pop
 #elif defined(__GNUC__)
