@@ -257,8 +257,8 @@ class IceGridTestCase(TestCase):
             varStr = " ".join(["{0}={1}".format(k, val(v)) for k,v in variables.items()])
             targets = " ".join(self.targets)
             application = self.application
-            if isinstance(self.mapping, CSharpMapping) and current.config.dotnetcore:
-                application = application.replace(".xml", ".netcoreapp.xml")
+            if isinstance(self.mapping, CSharpMapping) and current.config.dotnet:
+                application = application.replace(".xml", ".dotnet.xml")
             self.runadmin(current, "application add -n {0} {1} {2}".format(application, varStr, targets))
 
     def teardownClientSide(self, current, success):
