@@ -7,7 +7,7 @@ from Util import *
 class UdpTestCase(ClientServerTestCase):
 
     def setupServerSide(self, current):
-        if current.config.android or current.config.xamarin:
+        if current.config.android:
             self.servers = [Server(ready="McastTestAdapter")]
         else:
             self.servers = [Server(args=[i], ready="McastTestAdapter") for i in range(0, 5)]
@@ -18,9 +18,4 @@ class UdpTestCase(ClientServerTestCase):
         else:
             self.clients = [Client(args=[5])]
 
-#
-# With UWP, we can't run the UDP tests with the C++ servers (used when SSL is enabled).
-#
-options=lambda current: { "protocol": ["tcp", "ws"] } if current.config.uwp else {}
-
-TestSuite(__name__, [ UdpTestCase() ], multihost=False, options=options)
+TestSuite(__name__, [ UdpTestCase() ], multihost=False)
