@@ -90,12 +90,8 @@ class IceSSLConfigurationServer(Server):
         if isinstance(platform, Windows) and current.config.openssl:
             return "serveropenssl"
         return Server.getExe(self, current)
-#
-# With UWP, we can't run this test with the UWP C++ server (used with tcp/ws)
-#
-options=lambda current: { "protocol": ["ssl", "wss"] } if current.config.uwp else {}
 
 TestSuite(__name__, [
    ConfigurationTestCase(client=IceSSLConfigurationClient(args=['"{testdir}"']),
                          server=IceSSLConfigurationServer(args=['"{testdir}"']))
-], multihost=False, options=options)
+], multihost=False)
