@@ -12,7 +12,7 @@ import IceImpl
 // should check `factoriesRegistered' to ensure lazzy initinialization occurrs before
 // the factories are used.
 //
-internal let factoriesRegistered: Bool = {
+let factoriesRegistered: Bool = {
     ICEUtil.registerFactories(exception: ExceptionFactory.self,
                               connectionInfo: ConnectionInfoFactory.self,
                               endpointInfo: EndpointInfoFactory.self,
@@ -159,6 +159,7 @@ private func initializeImpl(args: [String],
         } else {
             // swiftlint:disable force_cast
             return (communicator, remArgs as! [String])
+            // swiftlint:enable force_cast
         }
     }
 }
@@ -222,6 +223,7 @@ public func createProperties(_ args: inout [String], defaults: Properties? = nil
 
         // swiftlint:disable force_cast
         args = remArgs as! [String]
+        // swiftlint:enable force_cast
         return PropertiesI(handle: propertiesHandle)
     }
 }
@@ -230,11 +232,11 @@ public func createProperties(_ args: inout [String], defaults: Properties? = nil
 /// indicates the major version, BB indicates the minor version, and CC
 /// indicates the patch level. For example, for Ice 3.3.1, the returned
 /// value is 30301.
-public let intVersion: Int = 30709
+public let intVersion: Int = 30710
 
 /// The Ice version in the form A.B.C, where A indicates the major version,
 /// B indicates the minor version, and C indicates the patch level.
-public let stringVersion: String = "3.7.9"
+public let stringVersion: String = "3.7.10"
 
 public let Encoding_1_0 = EncodingVersion(major: 1, minor: 0)
 public let Encoding_1_1 = EncodingVersion(major: 1, minor: 1)
